@@ -1,12 +1,15 @@
 package App::pherkin;
-{
-  $App::pherkin::VERSION = '0.17';
-}
-
+$App::pherkin::VERSION = '0.26';
 use strict;
 use warnings;
+
 use FindBin::libs;
 use Getopt::Long;
+use Module::Runtime qw(use_module);
+use List::Util qw(max);
+
+use Test::BDD::Cucumber::I18n qw(languages langdef readable_keywords keyword_to_subname);
+use Test::BDD::Cucumber::Loader;
 
 use Moose;
 has 'tags' => ( is => 'rw', isa => 'ArrayRef', required => 0 );
@@ -18,7 +21,7 @@ App::pherkin - Run Cucumber tests from the command line
 
 =head1 VERSION
 
-version 0.17
+version 0.26
 
 =head1 SYNOPSIS
 
@@ -36,10 +39,6 @@ Steps that pass will be printed in green, those that fail in red, and those
 for which there is no step definition as yellow (for TODO), assuming you're
 using the default output harness.
 
-=cut
-
-use Test::BDD::Cucumber::Loader;
-
 =head1 METHODS
 
 =head2 run
@@ -55,6 +54,9 @@ Returns a L<Test::BDD::Cucumber::Model::Result> object for all steps run.
 sub run {
     my ( $self, @arguments ) = @_;
 
+    # localized features will have utf8 in them and options may output utf8 as well
+    binmode STDOUT, ':utf8';
+
     my ($options, @feature_files) = $self->_process_arguments(@arguments);
 
     my ( $executor, @features ) = Test::BDD::Cucumber::Loader->load(
@@ -62,9 +64,7 @@ sub run {
     );
     die "No feature files found" unless @features;
 
-    eval "require $options->{'harness'}" || die $@;
-    my $harness  = $options->{'harness'}->new();
-    $harness->startup();
+    my $harness = $self->_load_harness( $options->{'harness'} );
 
     my $tag_spec;
     if ($self->tag_scheme) {
@@ -77,6 +77,22 @@ sub run {
     return $harness->result;
 }
 
+sub _load_harness {
+    my ( $self, $harness_module ) = @_;
+
+    unless ( $harness_module =~ m/::/ ) {
+        $harness_module = "Test::BDD::Cucumber::Harness::" . $harness_module;
+    }
+
+    eval { use_module( $harness_module ) } ||
+        die "Unable to load harness [$harness_module]: $@";
+
+    my $harness = $harness_module->new();
+    $harness->startup();
+
+    return $harness;
+}
+
 sub _process_arguments {
     my ( $self, @args ) = @_;
     local @ARGV = @args;
@@ -87,19 +103,24 @@ sub _process_arguments {
     my $includes = [];
     my $tags = [];
     GetOptions(
-        'I=s@'   => \$includes,
-        'l|lib'  => \(my $add_lib),
-        'b|blib' => \(my $add_blib),
+        'I=s@'       => \$includes,
+        'l|lib'      => \(my $add_lib),
+        'b|blib'     => \(my $add_blib),
         'o|output=s' => \(my $harness),
-        't|tags=s@' => \$tags,
+	't|tags=s@'  => \$tags,
+	'i18n=s'     => \(my $i18n)
     );
+
+    if ($i18n) {
+        _print_langdef($i18n) unless $i18n eq 'help';
+        _print_languages();
+    };
+
     unshift @$includes, 'lib'                   if $add_lib;
     unshift @$includes, 'blib/lib', 'blib/arch' if $add_blib;
 
     # Munge the output harness
     $harness //= "TermColor";
-    $harness = "Test::BDD::Cucumber::Harness::$harness" unless
-        $harness =~ m/\:\:/;
 
     lib->import(@$includes) if @$includes;
 
@@ -143,6 +164,46 @@ sub _process_tags {
     return $tag_scheme;
 }
 
+sub _print_languages {
+
+    my @languages=languages();
+
+    my $max_code_length   = max map { length } @languages;
+    my $max_name_length   = max map { length(langdef($_)->{name}) } @languages;
+    my $max_native_length = max map { length(langdef($_)->{native}) } @languages;
+
+    my $format= "| %-${max_code_length}s | %-${max_name_length}s | %-${max_native_length}s |\n";
+
+    for my $language (sort @languages) {
+        my $langdef=langdef($language);
+	printf $format, $language, $langdef->{name}, $langdef->{native};
+    }
+    exit;
+}
+
+sub _print_langdef {
+    my ($language)=@_;
+
+    my $langdef=langdef($language);
+
+    my @keywords= qw(feature background scenario scenario_outline examples
+		     given when then and but);
+    my $max_length = max map { length readable_keywords ($langdef->{$_}) } @keywords;
+
+    my $format= "| %-16s | %-${max_length}s |\n";
+    for my $keyword (qw(feature background scenario scenario_outline
+			examples given when then and but )) {
+        printf $format, $keyword, readable_keywords($langdef->{$keyword});
+    }
+
+    my $codeformat= "| %-16s | %-${max_length}s |\n";
+    for my $keyword (qw(given when then )) {
+        printf $codeformat, $keyword.' (code)',
+          readable_keywords($langdef->{$keyword}, \&keyword_to_subname);
+    }
+
+    exit;
+}
 
 =head1 AUTHOR
 
@@ -150,7 +211,7 @@ Peter Sergeant C<pete@clueball.com>
 
 =head1 LICENSE
 
-Copyright 2011, Peter Sergeant; Licensed under the same terms as Perl
+Copyright 2011-2014, Peter Sergeant; Licensed under the same terms as Perl
 
 =cut
 
