@@ -1,15 +1,12 @@
 package Test::BDD::Cucumber::Harness;
-{
-  $Test::BDD::Cucumber::Harness::VERSION = '0.17';
-}
-
+$Test::BDD::Cucumber::Harness::VERSION = '0.26';
 =head1 NAME
 
 Test::BDD::Cucumber::Harness - Base class for creating harnesses
 
 =head1 VERSION
 
-version 0.17
+version 0.26
 
 =head1 DESCRIPTION
 
@@ -75,7 +72,10 @@ sub scenario_done { my ( $self, $scenario, $dataset ) = @_; }
 
 Called at the start and end of step execution respectively. Both methods
 accept a L<Test::BDD::Cucmber::StepContext> object. C<step_done> also accepts
-a L<Test::BDD::Cucumber::Model::Result> object.
+a L<Test::BDD::Cucumber::Model::Result> object and an arrayref of arrayrefs with
+locations of consolidated matches, for highlighting.
+
+ [ [2,5], [7,9] ]
 
 =cut
 
@@ -130,7 +130,7 @@ Peter Sergeant C<pete@clueball.com>
 
 =head1 LICENSE
 
-Copyright 2011, Peter Sergeant; Licensed under the same terms as Perl
+Copyright 2011-2014, Peter Sergeant; Licensed under the same terms as Perl
 
 =cut
 
