@@ -1,15 +1,12 @@
 package Test::BDD::Cucumber::Harness::Data;
-{
-  $Test::BDD::Cucumber::Harness::Data::VERSION = '0.17';
-}
-
+$Test::BDD::Cucumber::Harness::Data::VERSION = '0.26';
 =head1 NAME
 
 Test::BDD::Cucumber::Harness::Data - Builds up an internal data representation of test passes / failures
 
 =head1 VERSION
 
-version 0.17
+version 0.26
 
 =head1 DESCRIPTION
 
@@ -131,9 +128,10 @@ sub step {
 }
 
 sub step_done {
-    my ($self, $context, $result) = @_;
+    my ($self, $context, $result, $highlights) = @_;
 
     $self->current_step->{'result'} = $result;
+    $self->current_step->{'highlights'} = $highlights;
     push( @{ $self->current_scenario->{'steps'} }, $self->current_step );
     $self->current_step({});
 }
@@ -191,7 +189,7 @@ Peter Sergeant C<pete@clueball.com>
 
 =head1 LICENSE
 
-Copyright 2011, Peter Sergeant; Licensed under the same terms as Perl
+Copyright 2011-2014, Peter Sergeant; Licensed under the same terms as Perl
 
 =cut
 
